#!/bin/bash -l

# Get some variables provided by autosubmit.
WORKDIR=%HPCROOTDIR%
ICON_VERSION=%ICON_VERSION%

BGRID_GLOBAL=%simulation.BGRID_GLOBAL%
RGRID_GLOBAL=%simulation.RGRID_GLOBAL%

STARTDATE=%SDATE%

# Example of date format "2018-06-01T00:00:00Z"
START_YEAR=%Chunk_START_YEAR%
START_MONTH=%Chunk_START_MONTH%
START_DAY=%Chunk_START_DAY%
START_HOUR=%Chunk_START_HOUR%

END_YEAR=%Chunk_END_YEAR%
END_MONTH=%Chunk_END_MONTH%
END_DAY=%Chunk_END_DAY%
END_HOUR=%Chunk_END_HOUR%

Chunk_START_DATE="${START_YEAR}-${START_MONTH}-${START_DAY}T${START_HOUR}:00:00Z"
Chunk_END_DATE="${END_YEAR}-${END_MONTH}-${END_DAY}T${END_HOUR}:00:00Z"

MEMBER=%MEMBER%

# Define rundir
RUNDIR=${WORKDIR}/${STARTDATE}/${MEMBER}

cd ${RUNDIR}

cat >icon_master.namelist <<EOF
&master_nml
    lrestart                    = .false.
    lrestart_write_last         = .false.
/

&master_model_nml
    model_type =                1                       ! atmospheric model
    model_name =                "ATMO"                  ! name of this model component
    model_namelist_filename =   "icon_atmosphere.namelist"
/

&master_time_control_nml
    calendar                    = "proleptic gregorian"
    experimentStartDate         = '${Chunk_START_DATE}'
    experimentStopDate          = '${Chunk_END_DATE}'
/
EOF

cat >icon_atmosphere.namelist <<EOF
&run_nml
    ltestcase                   = .TRUE.        ! idealized testcase runs
    dtime                       = 300           ! time step of 300 seconds
    output                      = 'nml'         ! use output nameslists
    msg_level                   = 15
    nsteps                      = 72
    num_lev                     = 31
    lvert_nest                  = .false.
    ldynamics                   = .true.
    ltransport                  = .true.
    ntracer                     = 5
    iforcing                    = 3
/

&grid_nml
    dynamics_grid_filename      = '$BGRID_GLOBAL'
    radiation_grid_filename     = '$RGRID_GLOBAL'
    dynamics_parent_grid_id     = 0
    lredgrid_phys               = .true.
/

&nh_testcase_nml
    nh_test_name                = 'APE_nwp'   ! testcase selection
    ape_sst_case                = 'sst_qobs'
/

&nonhydrostatic_nml
    damp_height                 = 18000
    rayleigh_coeff              = 0.75
/

&nwp_phy_nml
    inwp_surface                = 0
/

&parallel_nml
    nproma                      = 16
/

! the following two output files are used to initialize the next run
&output_nml
    file_interval               = 'PT3600S'
    output_start                = '${Chunk_START_DATE}'
    output_end                  = '${Chunk_END_DATE}'
    output_filename             = "init-test"
    output_interval             = 'PT3600S'
    include_last                = .true.
    mode                        = 1
    taxis_tunit                 = 1
    ml_varlist                  = 'group:dwd_fg_atm_vars', 'group:dwd_fg_sfc_vars'
/
&output_nml
    steps_per_file              = 1
    output_start                = '${Chunk_START_DATE}'
    output_end                  = '${Chunk_START_DATE}'
    output_filename             = "init-test-ext"
    include_last                = .true.
    output_interval             = 'PT3600S'
    ml_varlist                  = 'depth_lk', 'emis_rad', 'fr_lake', 'fr_land', 'topography_c', 'soiltyp', 'sso_stdh', 'sso_theta', 'sso_gamma', 'sso_sigma'
/
EOF
